@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -41,7 +43,8 @@
 #'
 #' @details
 #' Vectorized over \code{str}, and \code{pattern} or \code{value}
-#' (replacement version).
+#' (replacement version) (with recycling
+#' of the elements in the shorter vector if necessary).
 #'
 #' \code{stri_subset} and \code{stri_subset<-} are convenience functions.
 #' They call either \code{stri_subset_regex},
@@ -69,129 +72,150 @@
 #' @return The \code{stri_subset} functions return a character vector.
 #' As usual, the output encoding is always UTF-8.
 #'
-#' The \code{stri_subset<-} function modifies the \code{str} object
-#' ``in-place''.
+#' The \code{stri_subset<-} function modifies the \code{str} object 'in-place'.
 #'
 #' @examples
-#' stri_subset_regex(c("stringi R", "123", "ID456", ""), "^[0-9]+$")
+#' stri_subset_regex(c('stringi R', '123', 'ID456', ''), '^[0-9]+$')
 #'
-#' x <- c("stringi R", "123", "ID456", "")
-#' stri_subset_regex(x, "[^0-9]+|^$") <- NA
+#' x <- c('stringi R', '123', 'ID456', '')
+#' stri_subset_regex(x, '[^0-9]+|^$') <- NA
 #' print(x)
 #'
-#' x <- c("stringi R", "123", "ID456", "")
-#' stri_subset_regex(x, "^[0-9]+$", negate=TRUE) <- NA
+#' x <- c('stringi R', '123', 'ID456', '')
+#' stri_subset_regex(x, '^[0-9]+$', negate=TRUE) <- NA
 #' print(x)
 #'
 #' @family search_subset
 #' @export
 #' @rdname stri_subset
-stri_subset <- function(str, ..., regex, fixed, coll, charclass) {
-   providedarg <- c("regex"=!missing(regex), "fixed"    =!missing(fixed),
-                    "coll" =!missing(coll),  "charclass"=!missing(charclass))
+stri_subset <- function(str, ..., regex, fixed, coll, charclass)
+{
+    providedarg <- c(
+        regex = !missing(regex),
+        fixed = !missing(fixed),
+        coll = !missing(coll),
+        charclass = !missing(charclass))
 
-   if (sum(providedarg) != 1)
-      stop("you have to specify either `regex`, `fixed`, `coll`, or `charclass`")
+    if (sum(providedarg) != 1)
+        stop("you have to specify either `regex`, `fixed`, `coll`, or `charclass`")
 
-   if (providedarg["regex"])
-      stri_subset_regex(str, regex, ...)
-   else if (providedarg["fixed"])
-      stri_subset_fixed(str, fixed, ...)
-   else if (providedarg["coll"])
-      stri_subset_coll(str, coll, ...)
-   else if (providedarg["charclass"])
-      stri_subset_charclass(str, charclass, ...)
+    if (providedarg["regex"])
+        stri_subset_regex(str, regex, ...)
+    else if (providedarg["fixed"])
+        stri_subset_fixed(str, fixed, ...)
+    else if (providedarg["coll"])
+        stri_subset_coll(str, coll, ...)
+    else if (providedarg["charclass"])
+        stri_subset_charclass(str, charclass, ...)
 }
 
 
 #' @export
 #' @rdname stri_subset
 #' @usage stri_subset(str, ..., regex, fixed, coll, charclass) <- value
-"stri_subset<-" <- function(str, ..., regex, fixed, coll, charclass, value) {
-   providedarg <- c("regex"=!missing(regex), "fixed"    =!missing(fixed),
-                    "coll" =!missing(coll),  "charclass"=!missing(charclass))
+"stri_subset<-" <- function(str, ..., regex, fixed, coll, charclass, value)
+{
+    providedarg <- c(
+        regex = !missing(regex),
+        fixed = !missing(fixed),
+        coll = !missing(coll),
+        charclass = !missing(charclass))
 
-   if (sum(providedarg) != 1)
-      stop("you have to specify either `regex`, `fixed`, `coll`, or `charclass`")
+    if (sum(providedarg) != 1)
+        stop("you have to specify either `regex`, `fixed`, `coll`, or `charclass`")
 
-   if (providedarg["regex"])
-      `stri_subset_regex<-`(str, regex, ..., value=value)
-   else if (providedarg["fixed"])
-      `stri_subset_fixed<-`(str, fixed, ..., value=value)
-   else if (providedarg["coll"])
-      `stri_subset_coll<-`(str, coll, ..., value=value)
-   else if (providedarg["charclass"])
-      `stri_subset_charclass<-`(str, charclass, ..., value=value)
+    if (providedarg["regex"])
+        `stri_subset_regex<-`(str, regex, ..., value = value)
+    else if (providedarg["fixed"])
+        `stri_subset_fixed<-`(str, fixed, ..., value = value)
+    else if (providedarg["coll"])
+        `stri_subset_coll<-`(str, coll, ..., value = value)
+    else if (providedarg["charclass"])
+        `stri_subset_charclass<-`(str, charclass, ..., value = value)
 }
 
 
 #' @export
 #' @rdname stri_subset
-stri_subset_fixed <- function(str, pattern, omit_na=FALSE, negate=FALSE, ..., opts_fixed=NULL) {
-   if (!missing(...))
-       opts_fixed <- do.call(stri_opts_fixed, as.list(c(opts_fixed, ...)))
-   .Call(C_stri_subset_fixed, str, pattern, omit_na, negate, opts_fixed)
+stri_subset_fixed <- function(str, pattern, omit_na = FALSE, negate = FALSE, ...,
+    opts_fixed = NULL)
+{
+    if (!missing(...))
+        opts_fixed <- do.call(stri_opts_fixed, as.list(c(opts_fixed, ...)))
+    .Call(C_stri_subset_fixed, str, pattern, omit_na, negate, opts_fixed)
 }
 
 
 #' @export
 #' @rdname stri_subset
 #' @usage stri_subset_fixed(str, pattern, negate=FALSE, ..., opts_fixed=NULL) <- value
-"stri_subset_fixed<-" <- function(str, pattern, negate=FALSE, ..., opts_fixed=NULL, value) {
-   if (!missing(...))
-       opts_fixed <- do.call(stri_opts_fixed, as.list(c(opts_fixed, ...)))
-   .Call(C_stri_subset_fixed_replacement, str, pattern, negate, opts_fixed, value)
+`stri_subset_fixed<-` <- function(str, pattern, negate = FALSE, ...,
+    opts_fixed = NULL,  value)
+{
+    if (!missing(...))
+        opts_fixed <- do.call(stri_opts_fixed, as.list(c(opts_fixed, ...)))
+    .Call(C_stri_subset_fixed_replacement, str, pattern, negate, opts_fixed, value)
 }
 
 
 #' @export
 #' @rdname stri_subset
-stri_subset_charclass <- function(str, pattern, omit_na=FALSE, negate=FALSE) {
-   .Call(C_stri_subset_charclass, str, pattern, omit_na, negate)
+stri_subset_charclass <- function(str, pattern, omit_na = FALSE, negate = FALSE)
+{
+    .Call(C_stri_subset_charclass, str, pattern, omit_na, negate)
 }
 
 
 #' @export
 #' @rdname stri_subset
 #' @usage stri_subset_charclass(str, pattern, negate=FALSE) <- value
-"stri_subset_charclass<-" <- function(str, pattern, negate=FALSE, value) {
-   .Call(C_stri_subset_charclass_replacement, str, pattern, negate, value)
+`stri_subset_charclass<-` <- function(str, pattern, negate = FALSE, value)
+{
+    .Call(C_stri_subset_charclass_replacement, str, pattern, negate, value)
 }
 
 
 #' @export
 #' @rdname stri_subset
-stri_subset_coll <- function(str, pattern, omit_na=FALSE, negate=FALSE, ..., opts_collator=NULL) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_subset_coll, str, pattern, omit_na, negate, opts_collator)
+stri_subset_coll <- function(str, pattern, omit_na = FALSE, negate = FALSE, ...,
+    opts_collator = NULL)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_subset_coll, str, pattern, omit_na, negate, opts_collator)
 }
 
 
 #' @export
 #' @rdname stri_subset
 #' @usage stri_subset_coll(str, pattern, negate=FALSE, ..., opts_collator=NULL) <- value
-"stri_subset_coll<-" <- function(str, pattern, negate=FALSE, ..., opts_collator=NULL, value) {
-   if (!missing(...))
-       opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
-   .Call(C_stri_subset_coll_replacement, str, pattern, negate, opts_collator, value)
+`stri_subset_coll<-` <- function(str, pattern, negate = FALSE, ..., opts_collator = NULL,
+    value)
+{
+    if (!missing(...))
+        opts_collator <- do.call(stri_opts_collator, as.list(c(opts_collator, ...)))
+    .Call(C_stri_subset_coll_replacement, str, pattern, negate, opts_collator, value)
 }
 
 
 #' @export
 #' @rdname stri_subset
-stri_subset_regex <- function(str, pattern, omit_na=FALSE, negate=FALSE, ..., opts_regex=NULL) {
-   if (!missing(...))
-       opts_regex <- do.call(stri_opts_regex, as.list(c(opts_regex, ...)))
-   .Call(C_stri_subset_regex, str, pattern, omit_na, negate, opts_regex)
+stri_subset_regex <- function(str, pattern, omit_na = FALSE, negate = FALSE, ...,
+    opts_regex = NULL)
+{
+    if (!missing(...))
+        opts_regex <- do.call(stri_opts_regex, as.list(c(opts_regex, ...)))
+    .Call(C_stri_subset_regex, str, pattern, omit_na, negate, opts_regex)
 }
 
 
 #' @export
 #' @rdname stri_subset
 #' @usage stri_subset_regex(str, pattern, negate=FALSE, ..., opts_regex=NULL) <- value
-"stri_subset_regex<-" <- function(str, pattern, negate=FALSE, ..., opts_regex=NULL, value) {
-   if (!missing(...))
-       opts_regex <- do.call(stri_opts_regex, as.list(c(opts_regex, ...)))
-   .Call(C_stri_subset_regex_replacement, str, pattern, negate, opts_regex, value)
+"stri_subset_regex<-" <- function(str, pattern, negate = FALSE, ..., opts_regex = NULL,
+    value)
+{
+    if (!missing(...))
+        opts_regex <- do.call(stri_opts_regex, as.list(c(opts_regex, ...)))
+    .Call(C_stri_subset_regex_replacement, str, pattern, negate, opts_regex, value)
 }
