@@ -1,5 +1,5 @@
-/* This file is part of the 'stringi' package for R.
- * Copyright (C) 2013-2016, Marek Gagolewski and Bartek Tartanus
+/* This file is part of the 'stringi' project.
+ * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,6 +39,19 @@
 #include "stri_container_utf16.h"
 
 
+
+/** Represents Regex Matcher's settings
+ *
+ * @version 1.4.7 (Marek Gagolewski, 2020-08-24)
+ */
+struct StriRegexMatcherOptions {
+    uint32_t flags;
+    int32_t stack_limit;
+    int32_t time_limit;
+};
+
+
+
 /**
  * A class to handle regex searches
  *
@@ -49,26 +62,29 @@
  *
  * @version 0.3-1 (Marek Gagolewski, 2014-05-27)
  *          BUGFIX: invalid matcher reuse on empty search string
+ *
+ * @version 1.3.1 (Marek Gagolewski, 2019-02-06)
+ *          #337: warn on empty search pattern here
  */
 class StriContainerRegexPattern : public StriContainerUTF16 {
 
-   private:
+private:
 
-      uint32_t flags; ///< RegexMatcher flags
-      RegexMatcher* lastMatcher; ///< recently used \code{RegexMatcher}
-      R_len_t lastMatcherIndex;  ///< used by vectorize_getMatcher
+    StriRegexMatcherOptions opts; ///< RegexMatcher options
+    RegexMatcher* lastMatcher; ///< recently used RegexMatcher
+    R_len_t lastMatcherIndex;  ///< used by vectorize_getMatcher
 
 
-   public:
+public:
 
-      static uint32_t getRegexFlags(SEXP opts_regex);
+    static StriRegexMatcherOptions getRegexOptions(SEXP opts_regex);
 
-      StriContainerRegexPattern();
-      StriContainerRegexPattern(SEXP rstr, R_len_t nrecycle, uint32_t flags);
-      StriContainerRegexPattern(StriContainerRegexPattern& container);
-      ~StriContainerRegexPattern();
-      StriContainerRegexPattern& operator=(StriContainerRegexPattern& container);
-      RegexMatcher* getMatcher(R_len_t i);
+    StriContainerRegexPattern();
+    StriContainerRegexPattern(SEXP rstr, R_len_t nrecycle, StriRegexMatcherOptions opts);
+    StriContainerRegexPattern(StriContainerRegexPattern& container);
+    ~StriContainerRegexPattern();
+    StriContainerRegexPattern& operator=(StriContainerRegexPattern& container);
+    RegexMatcher* getMatcher(R_len_t i);
 };
 
 #endif
