@@ -71,6 +71,11 @@ const char* stri__prepare_arg_string_1_notNA(SEXP x,  const char* argname);
 double      stri__prepare_arg_double_1_notNA(SEXP x,  const char* argname);
 int         stri__prepare_arg_integer_1_notNA(SEXP x, const char* argname);
 bool        stri__prepare_arg_logical_1_notNA(SEXP x, const char* argname);
+
+double      stri__prepare_arg_double_1_NA(SEXP x, const char* argname);
+int stri__prepare_arg_logical_1_NA(SEXP x, const char* argname);
+int stri__prepare_arg_integer_1_NA(SEXP x, const char* argname);
+
 const char* stri__prepare_arg_locale(SEXP loc,        const char* argname,
                                      bool allowdefault, bool allowna=false);
 const char* stri__prepare_arg_enc(SEXP loc,           const char* argname,
